@@ -132,7 +132,7 @@ class BUFRCodesHandle(CodesHandle):
         return self.__iter__()
 
     def as_namespace(self, namespace=None):
-        return {k: self.get(k) for k in self.keys(namespace=namespace)}
+        return {k: self.get(k, default=None) for k in self.keys(namespace=namespace)}
 
 
 class BUFRCodesReader(CodesReader):
@@ -459,6 +459,8 @@ class BUFRListMixIn(PandasMixIn):
         Pandas DataFrame
             See  :obj:`ls`.
 
+        Notes
+        -----
         The following calls are equivalent:
 
             .. code-block:: python
@@ -491,6 +493,8 @@ class BUFRListMixIn(PandasMixIn):
         Pandas DataFrame
             See  :obj:`ls`.
 
+        Notes
+        -----
         The following calls are equivalent:
 
             .. code-block:: python
@@ -565,6 +569,8 @@ class BUFRList(BUFRListMixIn, Index):
             Returns a new object with the filtered elements. It contains a view to the data in the
             original object, so no data is copied.
 
+        Notes
+        -----
         Filter conditions are specified by a set of **metadata** keys either by a dictionary (in
         ``*args``) or a set of ``**kwargs``. Both single or multiple keys are allowed to use and each
         can specify the following type of filter values:
@@ -681,3 +687,6 @@ class BUFRReader(BUFRInOneFile, Reader):
     def mutate_source(self):
         # A BUFRReader is a source itself
         return self
+
+    def default_encoder(self):
+        return Reader.default_encoder(self)
