@@ -48,10 +48,20 @@ def reader(source, path, *, magic=None, deeper_check=False, **kwargs):
 
 def memory_reader(source, buffer, *, magic=None, deeper_check=False, **kwargs):
     if _match_magic(magic, deeper_check):
-        from .memory import GribFieldListInMemory
-        from .memory import GribMessageMemoryReader
+        import io
 
-        return GribFieldListInMemory(source, GribMessageMemoryReader(buffer, **kwargs), **kwargs)
+        from .memory import GribFieldListInMemory
+        from .memory import GribStreamReader
+
+        # convert the memory buffer into a stream and use the stream reader. See
+        # https://github.com/ecmwf/earthkit-data/issues/740 for details
+        stream = io.BytesIO(buffer)
+        r = GribStreamReader(stream, **kwargs)
+        r = GribFieldListInMemory(source, r, **kwargs)
+        return r
+
+        # The implementation below cannot handle padding between messages
+        # return GribFieldListInMemory(source, GribMessageMemoryReader(buffer, **kwargs), **kwargs)
 
 
 def stream_reader(
