@@ -7,10 +7,8 @@
 # nor does it submit to any jurisdiction.
 #
 
-import itertools
+
 import logging
-import sys
-from functools import cached_property
 
 try:
     import cdsapi
@@ -19,27 +17,13 @@ except ImportError:
 
 import yaml
 
-from earthkit.data.core.thread import SoftThreadPool
 from earthkit.data.decorators import normalize
-from earthkit.data.utils import ensure_iterable
-from earthkit.data.utils.progbar import tqdm
+from earthkit.data.utils.request import FileRequestRetriever
+from earthkit.data.utils.request import RequestBuilder
 
 from .file import FileSource
 from .prompt import APIKeyPrompt
 
-if sys.version_info >= (3, 12):
-    from itertools import batched
-else:
-
-    def batched(iterable, n):
-        # batched('ABCDEFG', 3) --> ABC DEF G
-        if n < 1:
-            raise ValueError("n must be at least one")
-        it = iter(iterable)
-        while batch := tuple(itertools.islice(it, n)):
-            yield batch
-
-
 LOG = logging.getLogger(__name__)
 
 
@@ -104,34 +88,26 @@ class CdsRetriever(FileSource):
     CdsRetriever
     """
 
-    def __init__(self, dataset, *args, prompt=True, **kwargs):
+    def __init__(self, dataset, *args, request=None, prompt=True, **kwargs):
         super().__init__()
 
         self.prompt = prompt
-
         assert isinstance(dataset, str)
-        if args and kwargs:
-            raise TypeError("CdsRetriever: cannot specify request using both args and kwargs")
 
-        if not args:
-            args = (kwargs,)
-        assert all(isinstance(request, dict) for request in args)
-        self._args = args
+        self.dataset = dataset
+
+        request_builder = RequestBuilder(
+            self, *args, request=request, normaliser=self._normalise_request, **kwargs
+        )
+        self.request = request_builder.requests
 
         self.client()  # Trigger password prompt before threading
 
-        nthreads = min(self.config("number-of-download-threads"), len(self.requests))
+        # Download each request in parallel when the config allows it
+        retriever = FileRequestRetriever(self, retriever=self._retrieve_one)
+        self.path = retriever.retrieve(self.request, self.dataset)
 
-        if nthreads < 2:
-            self.path = [self._retrieve(dataset, r) for r in self.requests]
-        else:
-            with SoftThreadPool(nthreads=nthreads) as pool:
-                futures = [pool.submit(self._retrieve, dataset, r) for r in self.requests]
-
-                iterator = (f.result() for f in futures)
-                self.path = list(tqdm(iterator, leave=True, total=len(self.requests)))
-
-    def _retrieve(self, dataset, request):
+    def _retrieve_one(self, request, dataset):
         def retrieve(target, args):
             cds_result = self.client().retrieve(args[0], args[1])
             self.source_filename = cds_result.location.split("/")[-1]
@@ -146,27 +122,13 @@ class CdsRetriever(FileSource):
 
     @staticmethod
     @normalize("area", "bounding-box(list)")
-    def _normalize_request(**kwargs):
+    def _normalise_request(**kwargs):
         return kwargs
 
-    @cached_property
+    # TODO: review if we need this property
+    @property
     def requests(self):
-        requests = []
-        for arg in self._args:
-            request = self._normalize_request(**arg)
-            split_on = request.pop("split_on", None)
-            if split_on is None:
-                requests.append(request)
-                continue
-
-            if not isinstance(split_on, dict):
-                split_on = {k: 1 for k in ensure_iterable(split_on)}
-            for values in itertools.product(
-                *[batched(ensure_iterable(request[k]), v) for k, v in split_on.items()]
-            ):
-                subrequest = dict(zip(split_on, values))
-                requests.append({**request, **subrequest})
-        return requests
+        return self.request
 
     def client(self):
         return client(self.prompt)
