@@ -18,6 +18,7 @@ except ImportError:
 
 from earthkit.data.sources.file import FileSource
 from earthkit.data.sources.stream import StreamSource
+from earthkit.data.utils.request import RequestBuilder
 from earthkit.data.utils.request import RequestMapper
 
 from . import Source
@@ -26,7 +27,7 @@ LOG = logging.getLogger(__name__)
 
 
 class FDBSource(Source):
-    def __init__(self, *args, stream=True, config=None, userconfig=None, lazy=False, **kwargs):
+    def __init__(self, *args, request=None, stream=True, config=None, userconfig=None, lazy=False, **kwargs):
         super().__init__()
 
         for k in ["group_by", "batch_size"]:
@@ -47,10 +48,16 @@ class FDBSource(Source):
 
         self.stream = stream
 
-        self.request = {}
-        for a in args:
-            self.request.update(a)
-        self.request.update(kwargs)
+        request_builder = RequestBuilder(self, *args, request=request, **kwargs)
+        self.request = request_builder.requests
+
+        if len(self.request) == 0:
+            raise ValueError("FDBSource: no requests to process")
+
+        if len(self.request) > 1:
+            raise ValueError("FDBSource: multiple requests are not supported")
+
+        self.request = self.request[0]
 
         if not (config or userconfig):
             self._check_env()
