@@ -14,8 +14,9 @@ try:
 except ImportError:
     raise ImportError("WEkEO access requires 'hda' to be installed")
 
-from earthkit.data.core.thread import SoftThreadPool
 from earthkit.data.decorators import normalize
+from earthkit.data.utils.request import FileRequestRetriever
+from earthkit.data.utils.request import RequestBuilder
 
 from .file import FileSource
 from .wekeo import EXTENSIONS
@@ -57,36 +58,23 @@ class WekeoCdsRetriever(FileSource):
     WekeoCdsRetriever
     """
 
-    def __init__(self, dataset, *args, prompt=True, **kwargs):
+    def __init__(self, dataset, *args, request=None, prompt=True, **kwargs):
         super().__init__()
 
         self.prompt = prompt
 
-        assert isinstance(dataset, str)
-        if len(args):
-            assert len(args) == 1
-            assert isinstance(args[0], dict)
-            assert not kwargs
-            kwargs = args[0]
-
-        requests = self.requests(**kwargs)
+        request_builder = RequestBuilder(
+            self, *args, request=request, normaliser=self._normalise_request, **kwargs
+        )
+        self.request = request_builder.requests
 
         self.client(self.prompt)  # Trigger password prompt before threading
 
-        nthreads = min(self.config("number-of-download-threads"), len(requests))
+        # Download each request in parallel when the config allows it
+        retriever = FileRequestRetriever(self, retriever=self._retrieve_one)
+        self.path = retriever.retrieve(self.request, dataset)
 
-        if nthreads < 2:
-            self.path = [self._retrieve(dataset, r) for r in requests]
-        else:
-            from earthkit.data.utils.progbar import tqdm
-
-            with SoftThreadPool(nthreads=nthreads) as pool:
-                futures = [pool.submit(self._retrieve, dataset, r) for r in requests]
-
-                iterator = (f.result() for f in futures)
-                self.path = list(tqdm(iterator, leave=True, total=len(requests)))
-
-    def _retrieve(self, dataset, request):
+    def _retrieve_one(self, request, dataset):
         def retrieve(target, args):
             self.client(self.prompt).retrieve(args[0], args[1], target)
 
@@ -98,19 +86,8 @@ class WekeoCdsRetriever(FileSource):
 
     @normalize("date", "date-list(%Y-%m-%d)")
     @normalize("area", "bounding-box(list)")
-    def requests(self, **kwargs):
-        split_on = kwargs.pop("split_on", None)
-        if split_on is None or not isinstance(kwargs.get(split_on), (list, tuple)):
-            return [kwargs]
-
-        result = []
-
-        for v in kwargs[split_on]:
-            r = dict(**kwargs)
-            r[split_on] = v
-            result.append(r)
-
-        return result
+    def _normalise_request(self, **kwargs):
+        return kwargs
 
     @staticmethod
     def client(use_prompt):
