@@ -32,7 +32,9 @@ class OfflineError(Exception):
 
 _NETWORK_PATCHER = patch("socket.socket", side_effect=OfflineError)
 
-_REMOTE_TEST_DATA_URL = "https://get.ecmwf.int/repository/test-data/earthkit-data/"
+_REMOTE_ROOT_URL = "https://sites.ecmwf.int/repository/earthkit-data/"
+_REMOTE_TEST_DATA_URL = "https://sites.ecmwf.int/repository/earthkit-data/test-data/"
+_REMOTE_EXAMPLES_URL = "https://sites.ecmwf.int/repository/earthkit-data/examples/"
 
 _ROOT_DIR = top = os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(__file__))))
 if not os.path.exists(os.path.join(_ROOT_DIR, "tests", "data")):
@@ -57,10 +59,18 @@ def preserve_cwd():
         os.chdir(current_dir)
 
 
+def earthkit_remote_file(*args):
+    return os.path.join(_REMOTE_ROOT_URL, *args)
+
+
 def earthkit_remote_test_data_file(*args):
     return os.path.join(_REMOTE_TEST_DATA_URL, *args)
 
 
+def earthkit_remote_examples_file(*args):
+    return os.path.join(_REMOTE_EXAMPLES_URL, *args)
+
+
 def earthkit_file(*args):
     return os.path.join(_ROOT_DIR, *args)
 
@@ -89,7 +99,7 @@ def modules_installed(*modules):
     for module in modules:
         try:
             import_module(module)
-        except ImportError:
+        except (ImportError, RuntimeError):
             return False
     return True
 
@@ -120,7 +130,7 @@ if not NO_PROD_FDB:
     fdb_home = os.environ.get("FDB_HOME", None)
     NO_PROD_FDB = fdb_home is None
 
-
+NO_GRIBJUMP = NO_FDB or not modules_installed("pygribjump")
 NO_POLYTOPE = not os.path.exists(os.path.expanduser("~/.polytopeapirc"))
 NO_COVJSONKIT = not modules_installed("covjsonkit")
 NO_RIOXARRAY = not modules_installed("rioxarray")
