@@ -11,7 +11,6 @@ import itertools
 import logging
 import os
 import re
-from functools import cached_property
 from pathlib import Path
 from typing import Any as TypingAny
 from typing import Dict
@@ -20,6 +19,8 @@ from typing import Optional
 from typing import Tuple
 from typing import Union
 
+from earthkit.data.decorators import thread_safe_cached_property
+
 from .dates import to_datetime
 from .dates import to_timedelta
 
@@ -662,14 +663,14 @@ class Pattern:
             t += f"\n {p}"
         return t
 
-    @cached_property
+    @thread_safe_cached_property
     def regex(self) -> re.Pattern:
         t = ""
         for p in self.pattern:
             if isinstance(p, Constant):
                 t += p.value
             else:
-                t += f"(?P<{p.name}>\S+)"
+                t += rf"(?P<{p.name}>\S+)"
 
         t = rf"^{t}$"
         return re.compile(t)
