@@ -17,6 +17,7 @@ from earthkit.data.testing import earthkit_remote_test_data_file
 
 
 @pytest.mark.cache
+@pytest.mark.parametrize("allow_holes", [False, True])
 @pytest.mark.parametrize(
     "url_suffix,kwargs,num,variables,dim_keys,split_values",
     [
@@ -90,11 +91,11 @@ from earthkit.data.testing import earthkit_remote_test_data_file
         # ({"squeeze": False}, "param", ["r", "t"], ["time", "step", "levelist"]),
     ],
 )
-def test_xr_split(url_suffix, kwargs, num, variables, dim_keys, split_values):
-    ds_ek = from_source("url", earthkit_remote_test_data_file("test-data", "xr_engine", *url_suffix))
+def test_xr_split(allow_holes, url_suffix, kwargs, num, variables, dim_keys, split_values):
+    ds_ek = from_source("url", earthkit_remote_test_data_file("xr_engine", *url_suffix))
 
     dim_keys = dim_keys + ["latitude", "longitude"]
-    ds_lst, split_coords_lst = ds_ek.to_xarray(**kwargs)
+    ds_lst, split_coords_lst = ds_ek.to_xarray(allow_holes=allow_holes, **kwargs)
     assert len(ds_lst) == num
     assert len(split_coords_lst) == len(split_values)
 
